pub struct ServiceSubscriber2Proxy { /* private fields */ }Implementations
Sourceimpl ServiceSubscriber2Proxy
impl ServiceSubscriber2Proxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.net.mdns/ServiceSubscriber2.
Sourcepub fn take_event_stream(&self) -> ServiceSubscriber2EventStream
pub fn take_event_stream(&self) -> ServiceSubscriber2EventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn subscribe_to_service(
&self,
service: &str,
options: &ServiceSubscriptionOptions,
listener: ClientEnd<ServiceSubscriptionListenerMarker>,
) -> Result<(), Error>
pub fn subscribe_to_service( &self, service: &str, options: &ServiceSubscriptionOptions, listener: ClientEnd<ServiceSubscriptionListenerMarker>, ) -> Result<(), Error>
Subscribes to a service. The subscription lasts until subscriber is unbound.
- request
servicename of the type of service to which to subscribe. For example, cast uses ‘_googlecast._tcp.’. If this value is not a valid service name,subscriberis closed immediately and an error message is logged. - request
optionsoptions to be applied to the subscription. - request
listenerclient end of theServiceSubscriptionListenerchannel.
Sourcepub fn subscribe_to_all_services(
&self,
options: &ServiceSubscriptionOptions,
listener: ClientEnd<ServiceSubscriptionListenerMarker>,
) -> Result<(), Error>
pub fn subscribe_to_all_services( &self, options: &ServiceSubscriptionOptions, listener: ClientEnd<ServiceSubscriptionListenerMarker>, ) -> Result<(), Error>
Subscribes to all services. The subscription lasts until subscriber is unbound.
- request
optionsoptions to be applied to the subscription. - request
listenerclient end of theServiceSubscriptionListenerchannel.